@@ -268,12 +268,13 @@ class PytestBrownieRunner(PytestBrownieBase):
 
         # save results for this test
         results = self.results[path]
-        if report.when == "call":
-            results[idx] = convert_outcome(report.outcome)
-            if hasattr(report, "wasxfail"):
-                results[idx] = "x" if report.skipped else "X"
-        elif report.failed:
-            results[idx] = "E"
+        if not self.skip.get(report.nodeid):
+            if report.when == "call":
+                results[idx] = convert_outcome(report.outcome)
+                if hasattr(report, "wasxfail"):
+                    results[idx] = "x" if report.skipped else "X"
+            elif report.failed:
+                results[idx] = "E"
         if report.when != "teardown" or idx < len(self.node_map[path]) - 1:
             return
 
@@ -365,6 +366,9 @@ class PytestBrownieRunner(PytestBrownieBase):
             locals_dict = {k: v for k, v in locals_dict.items() if not k.startswith("@")}
 
             namespace = {"_callinfo": call, **globals_dict, **locals_dict}
+            if "tx" not in namespace and brownie.history:
+                # make it easier to look at the most recent transaction
+                namespace["tx"] = brownie.history[-1]
 
             try:
                 CONFIG.argv["cli"] = "console"
